[Bug 59664] New: BufferReader return fuzzied when use https transfer Unicode char

2016-06-06 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=59664

Bug ID: 59664
   Summary: BufferReader return fuzzied when use https transfer
Unicode char
   Product: Tomcat 7
   Version: 7.0.69
  Hardware: All
OS: Linux
Status: NEW
  Severity: normal
  Priority: P2
 Component: Servlet & JSP API
  Assignee: dev@tomcat.apache.org
  Reporter: else.liuj...@huawei.com

The questions same with Bug 53717,but i think the class BufferReader should be
improve.

OS:Win7 SP1
Tomcat:7.0.69 (Win7 and Suse11) 
JDK:1.8.0_65-b17


I code a win32 program and use winhttp5.1 API,to send HTTPs request to
Tomcat,the Body is Unicode content.

On Tomcat,JSP use BufferedReader to get it

The problem is:

The first times to do "read(cbuf,0,1024);",it return 0.

0 means the stream is ended. 

Because the first batch data is only 1 Byte,but Unicode need 2 bytes to encode.

it seems the same with Bug 53717.

That means BufferedReader can not used actually
Because when I coding JSP,i don't know how the Body will be split.
I not know the protocol is HTTPs or HTTP

i think the return of BufferedReader.read() should append a new enumeration
when character lacked.

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 58626] Tomcat does not start at boot time due to SIGHUP

2016-06-06 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=58626

--- Comment #25 from Michael Osipov <1983-01...@gmx.net> ---
I can happily confirm that the patch from trunk works on HP-UX. Tomcat comes up
as expected. Regarding the PID file:

> smartld@blnn724x - /var/opt/tomcat/work
> bash $ pwd
> /var/opt/tomcat/work
> 
> smartld@blnn724x - /var/opt/tomcat/work
> bash $ less catalina.pid
> 1961
> 
> smartld@blnn724x - /var/opt/tomcat/work
> bash $ ps -fu smartld | grep /tomcat/conf
>  smartld  1961 1  0 11:13:58 ? 0:49 /opt/java8/bin/java > 
> -Djava.util.logging.config.file=/var/opt/tomcat/conf/logging.properties 
> -Djava.util.logging.manager=org.apa

Thanks a lot for the patch. I can remove the sed patch with the upgrade to
6.0.46.

-- 
You are receiving this mail because:
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 55087] tomcat crashes in tcnative-1.dll with OCSP when OCSP server is not reachable

2016-06-06 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=55087

Ravi  changed:

   What|Removed |Added

 CC||ravi...@gmail.com

--- Comment #1 from Ravi  ---
Created attachment 33912
  --> https://bz.apache.org/bugzilla/attachment.cgi?id=33912&action=edit
Crash_Log_06_06_2016

Hi,

We have ran into similar crash and stack trace. Attaching the log.

Can someone please update the status of this defect?

Regards,
Ravi

-- 
You are receiving this mail because:
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 55087] tomcat crashes in tcnative-1.dll with OCSP when OCSP server is not reachable

2016-06-06 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=55087

Ravi  changed:

   What|Removed |Added

  Attachment #33912|0   |1
is obsolete||

--- Comment #2 from Ravi  ---
Created attachment 33913
  --> https://bz.apache.org/bugzilla/attachment.cgi?id=33913&action=edit
CrashLog

-- 
You are receiving this mail because:
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 59661] MailSessionFactory ignores system properties

2016-06-06 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=59661

--- Comment #5 from Michael Osipov <1983-01...@gmx.net> ---
Created attachment 33915
  --> https://bz.apache.org/bugzilla/attachment.cgi?id=33915&action=edit
Patch for Tomcat 6.0

-- 
You are receiving this mail because:
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 59661] MailSessionFactory ignores system properties

2016-06-06 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=59661

--- Comment #6 from Michael Osipov <1983-01...@gmx.net> ---
Created attachment 33916
  --> https://bz.apache.org/bugzilla/attachment.cgi?id=33916&action=edit
Patch for Tomcat 9.0

-- 
You are receiving this mail because:
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 59635] PerMessageDeflate.sendMassagePart() IllegalArgumentException using atmosphere

2016-06-06 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=59635

Mark Thomas  changed:

   What|Removed |Added

 Resolution|--- |WORKSFORME
 Status|NEW |RESOLVED

--- Comment #3 from Mark Thomas  ---
The provided test case works without error with 9.0.x, 8.5.x, 8.0.x and the
8.0.33 tag.

-- 
You are receiving this mail because:
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 59661] MailSessionFactory ignores system properties

2016-06-06 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=59661

--- Comment #7 from Michael Osipov <1983-01...@gmx.net> ---
Added patches against 6.0 trunk and 9.0 trunk. Tests pass.

I have removed the two default properties:
* "smtp" is the default transport of none is set, see Session#getTransport()
* Default mail localhost is derived from
InetAdress.getLocalHost().getHostName(). This shall do in most cases.
* Overriding system properties implicitly may cause problems

-- 
You are receiving this mail because:
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1746989 - in /tomcat/trunk: java/org/apache/jasper/compiler/TagLibraryInfoImpl.java java/org/apache/jasper/resources/LocalStrings.properties webapps/docs/changelog.xml

2016-06-06 Thread markt
Author: markt
Date: Mon Jun  6 13:23:45 2016
New Revision: 1746989

URL: http://svn.apache.org/viewvc?rev=1746989&view=rev
Log:
Fix https://bz.apache.org/bugzilla/show_bug.cgi?id=59654
Improve error message when attempting to use a TLD file from an invalid 
location.
Patch provided by Huxing Zhang.

Modified:
tomcat/trunk/java/org/apache/jasper/compiler/TagLibraryInfoImpl.java
tomcat/trunk/java/org/apache/jasper/resources/LocalStrings.properties
tomcat/trunk/webapps/docs/changelog.xml

Modified: tomcat/trunk/java/org/apache/jasper/compiler/TagLibraryInfoImpl.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/jasper/compiler/TagLibraryInfoImpl.java?rev=1746989&r1=1746988&r2=1746989&view=diff
==
--- tomcat/trunk/java/org/apache/jasper/compiler/TagLibraryInfoImpl.java 
(original)
+++ tomcat/trunk/java/org/apache/jasper/compiler/TagLibraryInfoImpl.java Mon 
Jun  6 13:23:45 2016
@@ -276,9 +276,11 @@ class TagLibraryInfoImpl extends TagLibr
 err.jspError("jsp.error.tld.missing_jar", uri);
 }
 return new TldResourcePath(url, uri, "META-INF/taglib.tld");
-} else {
-return new TldResourcePath(url, uri);
+} else if (uri.startsWith("/WEB-INF/lib/") || 
uri.startsWith("/WEB-INF/classes/") ||
+(uri.startsWith("/WEB-INF/tags/") && uri.endsWith(".tld")&& 
!uri.endsWith("implicit.tld"))) {
+err.jspError("jsp.error.tld.invalid_tld_file", uri);
 }
+return new TldResourcePath(url, uri);
 }
 
 private TagInfo createTagInfo(TagXml tagXml) throws JasperException {

Modified: tomcat/trunk/java/org/apache/jasper/resources/LocalStrings.properties
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/jasper/resources/LocalStrings.properties?rev=1746989&r1=1746988&r2=1746989&view=diff
==
--- tomcat/trunk/java/org/apache/jasper/resources/LocalStrings.properties 
(original)
+++ tomcat/trunk/java/org/apache/jasper/resources/LocalStrings.properties Mon 
Jun  6 13:23:45 2016
@@ -142,6 +142,7 @@ jsp.error.bad_attribute=Attribute {0} in
 jsp.error.tld.unable_to_get_jar=Unable to get JAR resource \"{0}\" containing 
TLD: {1}
 jsp.error.tld.missing=Unable to find taglib \"{0}\" for URI: {1}
 jsp.error.tld.missing_jar=Missing JAR resource \"{0}\" containing TLD
+jsp.error.tld.invalid_tld_file=Invalid tld file: \"{0}\", see JSP 
specification section 7.3.1 for more details
 jsp.error.unable.to_find_method=Unable to find setter method for attribute: {0}
 jsp.error.bad_tag=No tag \"{0}\" defined in tag library imported with prefix 
\"{1}\"
 jsp.error.xml.bad_tag=No tag \"{0}\" defined in tag library associated with 
uri \"{1}\"

Modified: tomcat/trunk/webapps/docs/changelog.xml
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/webapps/docs/changelog.xml?rev=1746989&r1=1746988&r2=1746989&view=diff
==
--- tomcat/trunk/webapps/docs/changelog.xml (original)
+++ tomcat/trunk/webapps/docs/changelog.xml Mon Jun  6 13:23:45 2016
@@ -131,6 +131,10 @@
 the class loader of the first web application to use expressions to be
 pinned in memory. (markt)
   
+  
+59654: Improve error message when attempting to use a TLD
+file from an invalid location. Patch provided by Huxing Zhang. (markt)
+  
 
   
   



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1746990 - in /tomcat/tc8.5.x/trunk: ./ java/org/apache/jasper/compiler/TagLibraryInfoImpl.java java/org/apache/jasper/resources/LocalStrings.properties webapps/docs/changelog.xml

2016-06-06 Thread markt
Author: markt
Date: Mon Jun  6 13:25:04 2016
New Revision: 1746990

URL: http://svn.apache.org/viewvc?rev=1746990&view=rev
Log:
Fix https://bz.apache.org/bugzilla/show_bug.cgi?id=59654
Improve error message when attempting to use a TLD file from an invalid 
location.
Patch provided by Huxing Zhang.

Modified:
tomcat/tc8.5.x/trunk/   (props changed)
tomcat/tc8.5.x/trunk/java/org/apache/jasper/compiler/TagLibraryInfoImpl.java

tomcat/tc8.5.x/trunk/java/org/apache/jasper/resources/LocalStrings.properties
tomcat/tc8.5.x/trunk/webapps/docs/changelog.xml

Propchange: tomcat/tc8.5.x/trunk/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Mon Jun  6 13:25:04 2016
@@ -1 +1 @@
-/tomcat/trunk:1734785,1734799,1734845,1734928,1735041,1735044,1735480,1735577,1735597,1735599-1735600,1735615,1736145,1736162,1736209,1736280,1736297,1736299,1736489,1736646,1736703,1736836,1736849,1737104-1737105,1737112,1737117,1737119-1737120,1737155,1737157,1737192,1737280,1737339,1737632,1737664,1737715,1737748,1737785,1737834,1737860,1737959,1738005,1738007,1738014-1738015,1738018,1738022,1738039,1738043,1738059-1738060,1738147,1738149,1738174-1738175,1738261,1738589,1738623-1738625,1738643,1738816,1738850,1738855,1738946-1738948,1738953-1738954,1738979,1738982,1739079-1739081,1739087,1739113,1739153,1739172,1739176,1739191,1739474,1739726,1739762,1739775,1739814,1739817-1739818,1739975,1740131,1740324,1740465,1740495,1740508-1740509,1740520,1740535,1740707,1740803,1740810,1740969,1740980,1740991,1740997,1741015,1741033,1741036,1741058,1741060,1741080,1741147,1741159,1741164,1741173,1741181,1741190,1741197,1741202,1741208,1741213,1741221,1741225,1741232,1741409,1741501,1741677
 
,1741892,1741896,1741984,1742023,1742042,1742071,1742090,1742093,1742101,1742105,1742111,1742139,1742146,1742148,1742166,1742181,1742184,1742187,1742246,1742248-1742251,1742263-1742264,1742268,1742276,1742369,1742387,1742448,1742509-1742512,1742917,1742919,1742933,1742975-1742976,1742984,1742986,1743019,1743115,1743117,1743124-1743125,1743134,1743425,1743554,1743679,1743696-1743698,1743700-1743701,1744058,1744064-1744065,1744125,1744194,1744229,1744270,1744323,1744432,1744684,1744697,1744705,1744713,1744760,1744786,1745142-1745143,1745145,1745177,1745179-1745180,1745227,1745248,1745254,1745337,1745467,1745576,1745735,1745744,1746304,1746306-1746307,1746319,1746327,1746338,1746340-1746341,1746344,1746427,1746441,1746473,1746490,1746492,1746495-1746496,1746499-1746501,1746503-1746507,1746509,1746549,1746551,1746554,1746556,1746558,1746584,1746620,1746649,1746724,1746939
+/tomcat/trunk:1734785,1734799,1734845,1734928,1735041,1735044,1735480,1735577,1735597,1735599-1735600,1735615,1736145,1736162,1736209,1736280,1736297,1736299,1736489,1736646,1736703,1736836,1736849,1737104-1737105,1737112,1737117,1737119-1737120,1737155,1737157,1737192,1737280,1737339,1737632,1737664,1737715,1737748,1737785,1737834,1737860,1737959,1738005,1738007,1738014-1738015,1738018,1738022,1738039,1738043,1738059-1738060,1738147,1738149,1738174-1738175,1738261,1738589,1738623-1738625,1738643,1738816,1738850,1738855,1738946-1738948,1738953-1738954,1738979,1738982,1739079-1739081,1739087,1739113,1739153,1739172,1739176,1739191,1739474,1739726,1739762,1739775,1739814,1739817-1739818,1739975,1740131,1740324,1740465,1740495,1740508-1740509,1740520,1740535,1740707,1740803,1740810,1740969,1740980,1740991,1740997,1741015,1741033,1741036,1741058,1741060,1741080,1741147,1741159,1741164,1741173,1741181,1741190,1741197,1741202,1741208,1741213,1741221,1741225,1741232,1741409,1741501,1741677
 
,1741892,1741896,1741984,1742023,1742042,1742071,1742090,1742093,1742101,1742105,1742111,1742139,1742146,1742148,1742166,1742181,1742184,1742187,1742246,1742248-1742251,1742263-1742264,1742268,1742276,1742369,1742387,1742448,1742509-1742512,1742917,1742919,1742933,1742975-1742976,1742984,1742986,1743019,1743115,1743117,1743124-1743125,1743134,1743425,1743554,1743679,1743696-1743698,1743700-1743701,1744058,1744064-1744065,1744125,1744194,1744229,1744270,1744323,1744432,1744684,1744697,1744705,1744713,1744760,1744786,1745142-1745143,1745145,1745177,1745179-1745180,1745227,1745248,1745254,1745337,1745467,1745576,1745735,1745744,1746304,1746306-1746307,1746319,1746327,1746338,1746340-1746341,1746344,1746427,1746441,1746473,1746490,1746492,1746495-1746496,1746499-1746501,1746503-1746507,1746509,1746549,1746551,1746554,1746556,1746558,1746584,1746620,1746649,1746724,1746939,1746989

Modified: 
tomcat/tc8.5.x/trunk/java/org/apache/jasper/compiler/TagLibraryInfoImpl.java
URL: 
http://svn.apache.org/viewvc/tomcat/tc8.5.x/trunk/java/org/apache/jasper/compiler/TagLibraryInfoImpl.java?rev=1746990&r1=1746989&r2=1746990&view=diff
==
--- 
tomcat/tc8.5.x/trunk/java/org/apache/jasper/compiler/TagLibraryInfoImpl.java 
(original)
+++ 
tomcat/tc8.5.x/trunk/java/org/apach

svn commit: r1746991 - in /tomcat/tc8.0.x/trunk: ./ java/org/apache/jasper/compiler/TagLibraryInfoImpl.java java/org/apache/jasper/resources/LocalStrings.properties webapps/docs/changelog.xml

2016-06-06 Thread markt
Author: markt
Date: Mon Jun  6 13:27:02 2016
New Revision: 1746991

URL: http://svn.apache.org/viewvc?rev=1746991&view=rev
Log:
Fix https://bz.apache.org/bugzilla/show_bug.cgi?id=59654
Improve error message when attempting to use a TLD file from an invalid 
location.
Patch provided by Huxing Zhang.

Modified:
tomcat/tc8.0.x/trunk/   (props changed)
tomcat/tc8.0.x/trunk/java/org/apache/jasper/compiler/TagLibraryInfoImpl.java

tomcat/tc8.0.x/trunk/java/org/apache/jasper/resources/LocalStrings.properties
tomcat/tc8.0.x/trunk/webapps/docs/changelog.xml

Propchange: tomcat/tc8.0.x/trunk/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Mon Jun  6 13:27:02 2016
@@ -1,2 +1,2 @@
 /tomcat/tc8.5.x/trunk:1735042,1737966,1743139-1743140,1744151
-/tomcat/trunk:1636524,1637156,1637176,1637188,1637331,1637684,1637695,1637890,1637892,1638720-1638725,1639653,1640010,1640083-1640084,1640088,1640275,1640322,1640347,1640361,1640365,1640403,1640410,1640652,1640655-1640658,1640688,1640700-1640883,1640903,1640976,1640978,1641000,1641026,1641038-1641039,1641051-1641052,1641058,1641064,1641300,1641369,1641374,1641380,1641486,1641634,1641656-1641692,1641704,1641707-1641718,1641720-1641722,1641735,1641981,1642233,1642280,1642554,1642564,1642595,1642606,1642668,1642679,1642697,1642699,1642766,1643002,1643045,1643054-1643055,1643066,1643121,1643128,1643206,1643209-1643210,1643216,1643249,1643270,1643283,1643309-1643310,1643323,1643365-1643366,1643370-1643371,1643465,1643474,1643536,1643570,1643634,1643649,1643651,1643654,1643675,1643731,1643733-1643734,1643761,1643766,1643814,1643937,1643963,1644017,1644169,1644201-1644203,1644321,1644323,1644516,1644523,1644529,1644535,1644730,1644768,1644784-1644785,1644790,1644793,1644815,1644884,1644886
 
,1644890,1644892,1644910,1644924,1644929-1644930,1644935,1644989,1645011,1645247,1645355,1645357-1645358,1645455,1645465,1645469,1645471,1645473,1645475,1645486-1645488,1645626,1645641,1645685,1645743,1645763,1645951-1645953,1645955,1645993,1646098-1646106,1646178,1646220,1646302,1646304,1646420,1646470-1646471,1646476,1646559,1646717-1646723,1646773,1647026,1647042,1647530,1647655,1648304,1648815,1648907,1649973,1650081,1650365,1651116,1651120,1651280,1651470,1652938,1652970,1653041,1653471,1653550,1653574,1653797,1653815-1653816,1653819,1653840,1653857,1653888,1653972,1654013,1654030,1654050,1654123,1654148,1654159,1654513,1654515,1654517,1654522,1654524,1654725,1654735,1654766,1654785,1654851-1654852,1654978,1655122-1655124,1655126-1655127,1655129-1655130,1655132-1655133,1655312,1655351,1655438,1655441,1655454,168,1656087,1656299,1656319,1656331,1656345,1656350,1656590,1656648-1656650,1656657,1657041,1657054,1657374,1657492,1657510,1657565,1657580,1657584,1657586,1657589,1657
 
592,1657607,1657609,1657682,1657907,1658207,1658734,1658781,1658790,1658799,1658802,1658804,1658833,1658840,1658966,1659043,1659053,1659059,1659174,1659184,1659188-1659189,1659216,1659263,1659293,1659304,1659306-1659307,1659382,1659384,1659428,1659471,1659486,1659505,1659516,1659521,1659524,1659559,1659562,1659803,1659806,1659814,1659833,1659862,1659905,1659919,1659948,1659967,1659983-1659984,1660060,1660074,1660077,1660133,1660168,1660331-1660332,1660353,1660358,1660924,1661386,1661770,1661867,1661972,1661990,1662200,1662308-1662309,1662548,1662614,1662696,1662736,1662985,1662988-1662989,1663264,1663277,1663298,1663534,1663562,1663676,1663715,1663754,1663768,1663772,1663781,1663893,1663995,1664143,1664163,1664174,1664301,1664317,1664347,1664657,1664659,1664710,1664863-1664864,1664866,1665085,1665292,1665559,1665653,1665661,1665672,1665694,1665697,1665736,1665779,1665976-1665977,1665980-1665981,1665985-1665986,1665989,1665998,1666004,1666008,1666013,1666017,1666024,1666116,1666386-1
 
666387,1666494,1666496,1666552,1666569,1666579,137,149,1666757,1666966,1666972,1666985,1666995,1666997,1667292,1667402,1667406,1667546,1667615,1667630,1667636,1667688,1667764,1667871,1668026,1668135,1668193,1668593,1668596,1668630,1668639,1668843,1669353,1669370,1669451,1669800,1669838,1669876,1669882,1670394,1670433,1670591,1670598-1670600,1670610,1670631,1670719,1670724,1670726,1670730,1670940,1671112,1672272,1672284,1673754,1674294,1675461,1675486,1675594,1675830,1676231,1676250-1676251,1676364,1676381,1676393,1676479,1676525,1676552,1676615,1676630,1676634,1676721,1676926,1676943,1677140,1677802,1678011,1678162,1678174,1678339,1678426-1678427,1678694,1678701,1679534,1679708,1679710,1679716,1680034,1680246,1681056,1681123,1681138,1681280,1681283,1681286,1681450,1681697,1681699,1681701,1681729,1681770,1681779,1681793,1681807,1681837-1681838,1681854,1681862,1681958,1682028,1682033,1682311,1682315,1682317,1682320,1682324,1682330,1682842,1684172,1684366,1684383,1684526-168452
 
7,1684549-1684550,1685556,1685591,1685739,1685744,1685772,1685816,1685826,1685891,1687242,1687261,1687268,1687340,1687544,1687551,1688563,1688841,1688878,165,

[Bug 59654] Jsp spec violation in tld identifying?

2016-06-06 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=59654

--- Comment #2 from Mark Thomas  ---
The improved message part of the fix has been applied to:
- 9.0.x for 9.0.0.M7 onwards
- 8.5.x for 8.5.3 onwards
- 8.0.x for 8.0.36 onwards

-- 
You are receiving this mail because:
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[GUMP@vmgump]: Project tomcat-trunk-test-nio2 (in module tomcat-trunk) failed

2016-06-06 Thread Bill Barker
To whom it may engage...

This is an automated request, but not an unsolicited one. For 
more information please visit http://gump.apache.org/nagged.html, 
and/or contact the folk at gene...@gump.apache.org.

Project tomcat-trunk-test-nio2 has an issue affecting its community integration.
This issue affects 1 projects.
The current state of this project is 'Failed', with reason 'Build Failed'.
For reference only, the following projects are affected by this:
- tomcat-trunk-test-nio2 :  Tomcat 9.x, a web server implementing the Java 
Servlet 4.0,
...


Full details are available at:

http://vmgump.apache.org/gump/public/tomcat-trunk/tomcat-trunk-test-nio2/index.html

That said, some information snippets are provided here.

The following annotations (debug/informational/warning/error messages) were 
provided:
 -DEBUG- Dependency on commons-daemon exists, no need to add for property 
commons-daemon.native.src.tgz.
 -DEBUG- Dependency on commons-daemon exists, no need to add for property 
tomcat-native.tar.gz.
 -INFO- Failed with reason build failed
 -INFO- Project Reports in: 
/srv/gump/public/workspace/tomcat-trunk/output/logs-NIO2
 -INFO- Project Reports in: 
/srv/gump/public/workspace/tomcat-trunk/output/test-tmp-NIO2/logs
 -WARNING- No directory 
[/srv/gump/public/workspace/tomcat-trunk/output/test-tmp-NIO2/logs]



The following work was performed:
http://vmgump.apache.org/gump/public/tomcat-trunk/tomcat-trunk-test-nio2/gump_work/build_tomcat-trunk_tomcat-trunk-test-nio2.html
Work Name: build_tomcat-trunk_tomcat-trunk-test-nio2 (Type: Build)
Work ended in a state of : Failed
Elapsed: 48 mins 42 secs
Command Line: /usr/lib/jvm/java-8-oracle/bin/java -Djava.awt.headless=true 
-Dbuild.sysclasspath=only org.apache.tools.ant.Main 
-Dgump.merge=/srv/gump/public/gump/work/merge.xml 
-Djunit.jar=/srv/gump/public/workspace/junit/target/junit-4.13-SNAPSHOT.jar 
-Dobjenesis.jar=/srv/gump/public/workspace/objenesis/main/target/objenesis-2.5-SNAPSHOT.jar
 -Dtest.reports=output/logs-NIO2 
-Dtomcat-native.tar.gz=/srv/gump/public/workspace/apache-commons/daemon/dist/bin/commons-daemon-20160606-native-src.tar.gz
 -Dexamples.sources.skip=true 
-Dbase.path=/srv/gump/public/workspace/tomcat-trunk/tomcat-build-libs 
-Djdt.jar=/srv/gump/packages/eclipse/plugins/R-4.5-201506032000/ecj-4.5.jar 
-Dtest.relaxTiming=true 
-Dcommons-daemon.jar=/srv/gump/public/workspace/apache-commons/daemon/dist/commons-daemon-20160606.jar
 
-Dcommons-daemon.native.src.tgz=/srv/gump/public/workspace/apache-commons/daemon/dist/bin/commons-daemon-20160606-native-src.tar.gz
 -Dtest.temp=output/test-tmp-NIO2 -Dtest.accesslog=true -Dexecute
 .test.nio=false 
-Dtest.openssl.path=/srv/gump/public/workspace/openssl-master/dest-20160606/bin/openssl
 -Dexecute.test.apr=false -Dtest.excludePerformance=true 
-Dexecute.test.nio2=true 
-Deasymock.jar=/srv/gump/public/workspace/easymock/core/target/easymock-3.5-SNAPSHOT.jar
 -Dhamcrest.jar=/srv/gump/packages/hamcrest/hamcrest-core-1.3.jar 
-Dcglib.jar=/srv/gump/packages/cglib/cglib-nodep-2.2.jar test 
[Working Directory: /srv/gump/public/workspace/tomcat-trunk]
CLASSPATH: 
/usr/lib/jvm/java-8-oracle/lib/tools.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/webapps/examples/WEB-INF/classes:/srv/gump/public/workspace/tomcat-trunk/output/testclasses:/srv/gump/public/workspace/ant/dist/lib/ant.jar:/srv/gump/public/workspace/ant/dist/lib/ant-launcher.jar:/srv/gump/public/workspace/ant/dist/lib/ant-jmf.jar:/srv/gump/public/workspace/ant/dist/lib/ant-junit.jar:/srv/gump/public/workspace/ant/dist/lib/ant-junit4.jar:/srv/gump/public/workspace/ant/dist/lib/ant-swing.jar:/srv/gump/public/workspace/ant/dist/lib/ant-apache-resolver.jar:/srv/gump/public/workspace/ant/dist/lib/ant-apache-xalan2.jar:/srv/gump/public/workspace/xml-commons/java/build/resolver.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/bin/bootstrap.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/bin/tomcat-juli.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/annotations-api.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/servlet-api.ja
 
r:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/jsp-api.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/el-api.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/websocket-api.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/jaspic-api.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/catalina.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/catalina-ant.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/catalina-storeconfig.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/tomcat-coyote.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/jasper.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/jasper-el.jar:/srv/gump/public/workspace/tomcat-trunk/output/build/lib/catalina-tribes.jar:/srv/gump/public/workspace/tomcat-trunk/outpu

svn commit: r1746994 - in /tomcat/tc7.0.x/trunk: java/org/apache/jasper/compiler/TagLibraryInfoImpl.java java/org/apache/jasper/resources/LocalStrings.properties webapps/docs/changelog.xml

2016-06-06 Thread markt
Author: markt
Date: Mon Jun  6 13:34:45 2016
New Revision: 1746994

URL: http://svn.apache.org/viewvc?rev=1746994&view=rev
Log:
Fix https://bz.apache.org/bugzilla/show_bug.cgi?id=59654
Enforce the requirements of section 7.3.1 of the JSP specification regarding 
the permitted locations for TLD files. Patch provided by Huxing Zhang.

Modified:
tomcat/tc7.0.x/trunk/java/org/apache/jasper/compiler/TagLibraryInfoImpl.java

tomcat/tc7.0.x/trunk/java/org/apache/jasper/resources/LocalStrings.properties
tomcat/tc7.0.x/trunk/webapps/docs/changelog.xml

Modified: 
tomcat/tc7.0.x/trunk/java/org/apache/jasper/compiler/TagLibraryInfoImpl.java
URL: 
http://svn.apache.org/viewvc/tomcat/tc7.0.x/trunk/java/org/apache/jasper/compiler/TagLibraryInfoImpl.java?rev=1746994&r1=1746993&r2=1746994&view=diff
==
--- 
tomcat/tc7.0.x/trunk/java/org/apache/jasper/compiler/TagLibraryInfoImpl.java 
(original)
+++ 
tomcat/tc7.0.x/trunk/java/org/apache/jasper/compiler/TagLibraryInfoImpl.java 
Mon Jun  6 13:34:45 2016
@@ -340,9 +340,14 @@ class TagLibraryInfoImpl extends TagLibr
 err.jspError("jsp.error.tld.missing_jar", uri);
 }
 return new TldLocation("META-INF/taglib.tld", url.toString());
-} else {
-return new TldLocation(uri);
+} else if (uri.startsWith("/WEB-INF/lib/")
+|| uri.startsWith("/WEB-INF/classes/") ||
+(uri.startsWith("/WEB-INF/tags/") && uri.endsWith(".tld")
+&& !uri.endsWith("implicit.tld"))) {
+err.jspError("jsp.error.tld.invalid_tld_file", uri);
 }
+
+return new TldLocation(uri);
 }
 
 private TagInfo createTagInfo(TreeNode elem, String jspVersion)

Modified: 
tomcat/tc7.0.x/trunk/java/org/apache/jasper/resources/LocalStrings.properties
URL: 
http://svn.apache.org/viewvc/tomcat/tc7.0.x/trunk/java/org/apache/jasper/resources/LocalStrings.properties?rev=1746994&r1=1746993&r2=1746994&view=diff
==
--- 
tomcat/tc7.0.x/trunk/java/org/apache/jasper/resources/LocalStrings.properties 
(original)
+++ 
tomcat/tc7.0.x/trunk/java/org/apache/jasper/resources/LocalStrings.properties 
Mon Jun  6 13:34:45 2016
@@ -212,6 +212,7 @@ jsp.error.bad_attribute=Attribute {0} in
 jsp.error.tld.unable_to_read=Unable to read TLD \"{1}\" from JAR file \"{0}\": 
{2}
 jsp.error.tld.unable_to_get_jar=Unable to get JAR resource \"{0}\" containing 
TLD: {1}
 jsp.error.tld.missing_jar=Missing JAR resource \"{0}\" containing TLD
+jsp.error.tld.invalid_tld_file=Invalid tld file: \"{0}\", see JSP 2.2 
specification section 7.3.1 for more details
 jsp.error.webxml_not_found=Could not locate web.xml
 jsp.cmd_line.usage=Usage: jsptoservlet [-dd ] 
[-keepgenerated] \
 <.jsp files>

Modified: tomcat/tc7.0.x/trunk/webapps/docs/changelog.xml
URL: 
http://svn.apache.org/viewvc/tomcat/tc7.0.x/trunk/webapps/docs/changelog.xml?rev=1746994&r1=1746993&r2=1746994&view=diff
==
--- tomcat/tc7.0.x/trunk/webapps/docs/changelog.xml (original)
+++ tomcat/tc7.0.x/trunk/webapps/docs/changelog.xml Mon Jun  6 13:34:45 2016
@@ -160,6 +160,11 @@
 the class loader of the first web application to use expressions to be
 pinned in memory. (markt)
   
+  
+59654: Enforce the requirements of section 7.3.1 of the JSP
+specification regarding the permitted locations for TLD files. Patch
+provided by Huxing Zhang. (markt)
+  
 
   
   



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1746995 - in /tomcat/tc6.0.x/trunk: ./ java/org/apache/jasper/compiler/TagLibraryInfoImpl.java java/org/apache/jasper/resources/LocalStrings.properties webapps/docs/changelog.xml

2016-06-06 Thread markt
Author: markt
Date: Mon Jun  6 13:42:20 2016
New Revision: 1746995

URL: http://svn.apache.org/viewvc?rev=1746995&view=rev
Log:
Fix https://bz.apache.org/bugzilla/show_bug.cgi?id=59654
Enforce the requirements of section 7.3.1 of the JSP specification regarding 
the permitted locations for TLD files. Patch provided by Huxing Zhang.

Modified:
tomcat/tc6.0.x/trunk/   (props changed)
tomcat/tc6.0.x/trunk/java/org/apache/jasper/compiler/TagLibraryInfoImpl.java

tomcat/tc6.0.x/trunk/java/org/apache/jasper/resources/LocalStrings.properties
tomcat/tc6.0.x/trunk/webapps/docs/changelog.xml

Propchange: tomcat/tc6.0.x/trunk/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Mon Jun  6 13:42:20 2016
@@ -1,4 +1,4 @@
-/tomcat/tc7.0.x/trunk:1190476,1224802,1243045,1298635,1304471,1311997,1312007,1331772,1333164,1333176,1348992,1354866,1371298,1371302,1371620,1402110,1409014,1413553,1413557,1413563,1430083,1438415,1446641-1446660,1447013,1453106,1453119,1484919,1486877,1500065,1503852,1505844,1513151,1521040,1526470,1536524,1539176-1539177,1544469,1544473,1552805,1558894,1558917,1561368,1561382,1561386,1561552,1561561,1561636,1561641,1561643,1561737,1562748,1564317,1568922,1570163,1577328,1577464-1577465,1578814,1586659,1586897,1586960,1588199,1588997,1589740,1589851,1589997,1590019,1590028,1590337,1590492,1590651,1590838,1590845,1590848,1590912,1593262,1593288,1593371,1593835,1594230,1595174,1595366,1600956,1601333,1601856,1601909,1609079,1609606,1617364,1617374,1617433,1617457-1617458,1624249,1626579,1627420,1627469,1632586,1637686,1637711,1640675,1642045,1643515,1643540,1643572,1643585-1643586,1643642,1643647,1644019,1648817,1656301,1658815,1659523,1659564,1664001,1664176,1665087,1666968,1666989
 
,1668541,1668635,1669802,1676557,1681183,1681841,1681865,1681867,1685829,1693109,1694293,1694433,1694875,1696381,1701945,1710353,1712656,1713873,1714000,1714005,1714540,1715213,1716221,1716417,1717107,1717210,1717212,1720236,1720398,1720443,1720464,1721814,1721883,1722645,1722801,1723151,1724435,1724553,1724675,1724797,1724806,1725931,1726631,1726808,1726813,1726815,1726817,1726819,1726917,1726919,1726922-1726924,1727031,1727034,1727043,1727158,1727672,1727903,1728450,1729363,1731010,1731119,1731956,1731978,1732362,1732674-1732675,1733942,1734116,1734134,1734532,1737249,1737253,1737968,1738049,1738186,1739778,1741178,1741184,1741193,1741211,1741218,1741228,1741235,1742281,1743121,1743142,1743649,1744061,1744129,1744155,1744241,1744383,1744689,1745230,1746942
+/tomcat/tc7.0.x/trunk:1190476,1224802,1243045,1298635,1304471,1311997,1312007,1331772,1333164,1333176,1348992,1354866,1371298,1371302,1371620,1402110,1409014,1413553,1413557,1413563,1430083,1438415,1446641-1446660,1447013,1453106,1453119,1484919,1486877,1500065,1503852,1505844,1513151,1521040,1526470,1536524,1539176-1539177,1544469,1544473,1552805,1558894,1558917,1561368,1561382,1561386,1561552,1561561,1561636,1561641,1561643,1561737,1562748,1564317,1568922,1570163,1577328,1577464-1577465,1578814,1586659,1586897,1586960,1588199,1588997,1589740,1589851,1589997,1590019,1590028,1590337,1590492,1590651,1590838,1590845,1590848,1590912,1593262,1593288,1593371,1593835,1594230,1595174,1595366,1600956,1601333,1601856,1601909,1609079,1609606,1617364,1617374,1617433,1617457-1617458,1624249,1626579,1627420,1627469,1632586,1637686,1637711,1640675,1642045,1643515,1643540,1643572,1643585-1643586,1643642,1643647,1644019,1648817,1656301,1658815,1659523,1659564,1664001,1664176,1665087,1666968,1666989
 
,1668541,1668635,1669802,1676557,1681183,1681841,1681865,1681867,1685829,1693109,1694293,1694433,1694875,1696381,1701945,1710353,1712656,1713873,1714000,1714005,1714540,1715213,1716221,1716417,1717107,1717210,1717212,1720236,1720398,1720443,1720464,1721814,1721883,1722645,1722801,1723151,1724435,1724553,1724675,1724797,1724806,1725931,1726631,1726808,1726813,1726815,1726817,1726819,1726917,1726919,1726922-1726924,1727031,1727034,1727043,1727158,1727672,1727903,1728450,1729363,1731010,1731119,1731956,1731978,1732362,1732674-1732675,1733942,1734116,1734134,1734532,1737249,1737253,1737968,1738049,1738186,1739778,1741178,1741184,1741193,1741211,1741218,1741228,1741235,1742281,1743121,1743142,1743649,1744061,1744129,1744155,1744241,1744383,1744689,1745230,1746942,1746994
 
/tomcat/tc8.0.x/trunk:1637685,1637709,1640674,1641726,1641729-1641730,1643513,1643539,1643571,1643581-1643582,1644018,1648816,1656300,1658801-1658803,1658811,1659522,1663997,1664175,1665086,1666967,1666988,1668634,1669801,1676556,1681182,1681840,1681864,1685827,1689921,1693108,1694291,1694427,1694873,1696379,1701944,1710347,1712618,1712655,1713872,1713998,1714004,1714538,1715207,1715866,1716216-1716217,1716414,1717208-1717209,1720235,1720396,1720442,1720463,1721813,1721882,1722800,1723130,1724434,1724674,1724792,1724803,1725929,1725963-1725965,1725970,1725974,1726172,1726175,1726179-1726182,1726195-1726198,1726200,1726203,1726226,1726

[Bug 59654] Jsp spec violation in tld identifying?

2016-06-06 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=59654

Mark Thomas  changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Resolution|--- |FIXED

--- Comment #3 from Mark Thomas  ---
Patch applied to 7.0.x for 7.0.70 onwards and 6.0p.x for 6.0.46 onwards.

--- tomcat/trunk/webapps/docs/changelog.xml (original)
+++ tomcat/trunk/webapps/docs/changelog.xml Mon Jun  6 14:17:16 2016
@@ -79,6 +79,11 @@
   
 Fix error message when failed to register MBean. (kfujino)
   
+  
+59655: Configure the cookie name validation to use RFC6265 
rules by default to
+align it with the default cookie parser. Document the impact system 
properties have on
+cookie name validation. (mark)
+  
 
   
   

Modified: tomcat/trunk/webapps/docs/config/systemprops.xml
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/webapps/docs/config/systemprops.xml?rev=1747014&r1=1747013&r2=1747014&view=diff
==
--- tomcat/trunk/webapps/docs/config/systemprops.xml (original)
+++ tomcat/trunk/webapps/docs/config/systemprops.xml Mon Jun  6 14:17:16 2016
@@ -280,6 +280,7 @@
   
org.apache.catalina.core.StandardHostValve.ACCESS_SESSION
   
org.apache.catalina.session.StandardSession.ACTIVITY_CHECK
   
org.apache.catalina.session.StandardSession.LAST_ACCESS_AT_START
+  
org.apache.tomcat.util.http.ServerCookie.STRICT_NAMING
   The URIEncoding attribute of any
   HTTP connector or
   AJP connector element.
@@ -335,7 +336,16 @@
 
org.apache.tomcat.websocket.server#isEnforceNoAddAfterHandshake
 (default changes from false to true)
   
+
 
+
+   If this is true then the requirements of the Servlet specification
+  that Cookie names must adhere to RFC2109 (no use of separators) will be
+  enforced. If this is false the the naming rules specified in RFC6265 will
+  be used.
+  If org.apache.catalina.STRICT_SERVLET_COMPLIANCE is set 
to
+  true, the default of this setting will be true,
+  else the default value will be false.
 
 
   



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1747015 - in /tomcat/tc8.5.x/trunk: ./ java/javax/servlet/http/Cookie.java webapps/docs/changelog.xml webapps/docs/config/systemprops.xml

2016-06-06 Thread markt
Author: markt
Date: Mon Jun  6 14:17:58 2016
New Revision: 1747015

URL: http://svn.apache.org/viewvc?rev=1747015&view=rev
Log:
Fix https://bz.apache.org/bugzilla/show_bug.cgi?id=59655
Configure the cookie name validation to use RFC6265 rules by default to align 
it with the default cookie parser. Document the impact system properties have 
on cookie name validation.

Modified:
tomcat/tc8.5.x/trunk/   (props changed)
tomcat/tc8.5.x/trunk/java/javax/servlet/http/Cookie.java
tomcat/tc8.5.x/trunk/webapps/docs/changelog.xml
tomcat/tc8.5.x/trunk/webapps/docs/config/systemprops.xml

Propchange: tomcat/tc8.5.x/trunk/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Mon Jun  6 14:17:58 2016
@@ -1 +1 @@
-/tomcat/trunk:1734785,1734799,1734845,1734928,1735041,1735044,1735480,1735577,1735597,1735599-1735600,1735615,1736145,1736162,1736209,1736280,1736297,1736299,1736489,1736646,1736703,1736836,1736849,1737104-1737105,1737112,1737117,1737119-1737120,1737155,1737157,1737192,1737280,1737339,1737632,1737664,1737715,1737748,1737785,1737834,1737860,1737959,1738005,1738007,1738014-1738015,1738018,1738022,1738039,1738043,1738059-1738060,1738147,1738149,1738174-1738175,1738261,1738589,1738623-1738625,1738643,1738816,1738850,1738855,1738946-1738948,1738953-1738954,1738979,1738982,1739079-1739081,1739087,1739113,1739153,1739172,1739176,1739191,1739474,1739726,1739762,1739775,1739814,1739817-1739818,1739975,1740131,1740324,1740465,1740495,1740508-1740509,1740520,1740535,1740707,1740803,1740810,1740969,1740980,1740991,1740997,1741015,1741033,1741036,1741058,1741060,1741080,1741147,1741159,1741164,1741173,1741181,1741190,1741197,1741202,1741208,1741213,1741221,1741225,1741232,1741409,1741501,1741677
 
,1741892,1741896,1741984,1742023,1742042,1742071,1742090,1742093,1742101,1742105,1742111,1742139,1742146,1742148,1742166,1742181,1742184,1742187,1742246,1742248-1742251,1742263-1742264,1742268,1742276,1742369,1742387,1742448,1742509-1742512,1742917,1742919,1742933,1742975-1742976,1742984,1742986,1743019,1743115,1743117,1743124-1743125,1743134,1743425,1743554,1743679,1743696-1743698,1743700-1743701,1744058,1744064-1744065,1744125,1744194,1744229,1744270,1744323,1744432,1744684,1744697,1744705,1744713,1744760,1744786,1745142-1745143,1745145,1745177,1745179-1745180,1745227,1745248,1745254,1745337,1745467,1745576,1745735,1745744,1746304,1746306-1746307,1746319,1746327,1746338,1746340-1746341,1746344,1746427,1746441,1746473,1746490,1746492,1746495-1746496,1746499-1746501,1746503-1746507,1746509,1746549,1746551,1746554,1746556,1746558,1746584,1746620,1746649,1746724,1746939,1746989
+/tomcat/trunk:1734785,1734799,1734845,1734928,1735041,1735044,1735480,1735577,1735597,1735599-1735600,1735615,1736145,1736162,1736209,1736280,1736297,1736299,1736489,1736646,1736703,1736836,1736849,1737104-1737105,1737112,1737117,1737119-1737120,1737155,1737157,1737192,1737280,1737339,1737632,1737664,1737715,1737748,1737785,1737834,1737860,1737959,1738005,1738007,1738014-1738015,1738018,1738022,1738039,1738043,1738059-1738060,1738147,1738149,1738174-1738175,1738261,1738589,1738623-1738625,1738643,1738816,1738850,1738855,1738946-1738948,1738953-1738954,1738979,1738982,1739079-1739081,1739087,1739113,1739153,1739172,1739176,1739191,1739474,1739726,1739762,1739775,1739814,1739817-1739818,1739975,1740131,1740324,1740465,1740495,1740508-1740509,1740520,1740535,1740707,1740803,1740810,1740969,1740980,1740991,1740997,1741015,1741033,1741036,1741058,1741060,1741080,1741147,1741159,1741164,1741173,1741181,1741190,1741197,1741202,1741208,1741213,1741221,1741225,1741232,1741409,1741501,1741677
 
,1741892,1741896,1741984,1742023,1742042,1742071,1742090,1742093,1742101,1742105,1742111,1742139,1742146,1742148,1742166,1742181,1742184,1742187,1742246,1742248-1742251,1742263-1742264,1742268,1742276,1742369,1742387,1742448,1742509-1742512,1742917,1742919,1742933,1742975-1742976,1742984,1742986,1743019,1743115,1743117,1743124-1743125,1743134,1743425,1743554,1743679,1743696-1743698,1743700-1743701,1744058,1744064-1744065,1744125,1744194,1744229,1744270,1744323,1744432,1744684,1744697,1744705,1744713,1744760,1744786,1745142-1745143,1745145,1745177,1745179-1745180,1745227,1745248,1745254,1745337,1745467,1745576,1745735,1745744,1746304,1746306-1746307,1746319,1746327,1746338,1746340-1746341,1746344,1746427,1746441,1746473,1746490,1746492,1746495-1746496,1746499-1746501,1746503-1746507,1746509,1746549,1746551,1746554,1746556,1746558,1746584,1746620,1746649,1746724,1746939,1746989,1747014

Modified: tomcat/tc8.5.x/trunk/java/javax/servlet/http/Cookie.java
URL: 
http://svn.apache.org/viewvc/tomcat/tc8.5.x/trunk/java/javax/servlet/http/Cookie.java?rev=1747015&r1=1747014&r2=1747015&view=diff
==
--- tomcat/tc8.5.x/trunk/java/javax/servlet/http/Cookie.java (original)
+++ tomcat/tc8.5.x/trunk/java/javax/servlet/http/Cookie.jav

[Bug 59655] The CookieNameValidator has issue that related to the consistency

2016-06-06 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=59655

Mark Thomas  changed:

   What|Removed |Added

 Resolution|--- |FIXED
 Status|NEW |RESOLVED

--- Comment #1 from Mark Thomas  ---
The CookieNameValidator can not be set per web application since it is set in
the specification implementation and can, therefore, only be set globally. I
have changed the default to the RFC6265 validator and restored the section of
the docs that describe the STRICT_NAMING property.

The fix has been applied to 9.0.x for 9.0.0.M7 onwards and 8.5.x for 8.5.3.
onwards.

-- 
You are receiving this mail because:
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



buildbot failure in on tomcat-trunk

2016-06-06 Thread buildbot
The Buildbot has detected a new failure on builder tomcat-trunk while building 
. Full details are available at:
https://ci.apache.org/builders/tomcat-trunk/builds/1433

Buildbot URL: https://ci.apache.org/

Buildslave for this Build: silvanus_ubuntu

Build Reason: The AnyBranchScheduler scheduler named 'on-tomcat-commit' 
triggered this build
Build Source Stamp: [branch tomcat/trunk] 1747014
Blamelist: markt

BUILD FAILED: failed compile_1

Sincerely,
 -The Buildbot




-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1747028 - in /tomcat/trunk/test: javax/servlet/http/TestCookie.java org/apache/tomcat/util/http/CookiesBaseTest.java org/apache/tomcat/util/http/TestCookiesNoStrictNamingSysProps.java

2016-06-06 Thread markt
Author: markt
Date: Mon Jun  6 15:20:11 2016
New Revision: 1747028

URL: http://svn.apache.org/viewvc?rev=1747028&view=rev
Log:
Unit test adjustments for change to default cookie name validator

Modified:
tomcat/trunk/test/javax/servlet/http/TestCookie.java
tomcat/trunk/test/org/apache/tomcat/util/http/CookiesBaseTest.java

tomcat/trunk/test/org/apache/tomcat/util/http/TestCookiesNoStrictNamingSysProps.java

Modified: tomcat/trunk/test/javax/servlet/http/TestCookie.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/test/javax/servlet/http/TestCookie.java?rev=1747028&r1=1747027&r2=1747028&view=diff
==
--- tomcat/trunk/test/javax/servlet/http/TestCookie.java (original)
+++ tomcat/trunk/test/javax/servlet/http/TestCookie.java Mon Jun  6 15:20:11 
2016
@@ -129,9 +129,9 @@ public class TestCookie {
 
 @Test
 public void strictNamingImpliesRFC2109() {
-// Not using strict naming here so this should be OK
+// Needs to be something RFC6265 allows, but strict naming does not.
 @SuppressWarnings("unused")
-Cookie cookie = new Cookie("@Foo", null);
+Cookie cookie = new Cookie("$Foo", null);
 }
 
 public static void checkCharInName(CookieNameValidator validator, BitSet 
allowed) {

Modified: tomcat/trunk/test/org/apache/tomcat/util/http/CookiesBaseTest.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/test/org/apache/tomcat/util/http/CookiesBaseTest.java?rev=1747028&r1=1747027&r2=1747028&view=diff
==
--- tomcat/trunk/test/org/apache/tomcat/util/http/CookiesBaseTest.java 
(original)
+++ tomcat/trunk/test/org/apache/tomcat/util/http/CookiesBaseTest.java Mon Jun  
6 15:20:11 2016
@@ -82,7 +82,7 @@ public abstract class CookiesBaseTest ex
 new CookieServlet("na/me", "value"));
 ctx.addServletMapping("/invalidFwd", "invalidFwd");
 Tomcat.addServlet(ctx, "invalidStrict",
-new CookieServlet("na?me", "value"));
+new CookieServlet("$name", "value"));
 ctx.addServletMapping("/invalidStrict", "invalidStrict");
 Tomcat.addServlet(ctx, "valid", new CookieServlet("name", "value"));
 ctx.addServletMapping("/valid", "valid");

Modified: 
tomcat/trunk/test/org/apache/tomcat/util/http/TestCookiesNoStrictNamingSysProps.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/test/org/apache/tomcat/util/http/TestCookiesNoStrictNamingSysProps.java?rev=1747028&r1=1747027&r2=1747028&view=diff
==
--- 
tomcat/trunk/test/org/apache/tomcat/util/http/TestCookiesNoStrictNamingSysProps.java
 (original)
+++ 
tomcat/trunk/test/org/apache/tomcat/util/http/TestCookiesNoStrictNamingSysProps.java
 Mon Jun  6 15:20:11 2016
@@ -54,7 +54,7 @@ public class TestCookiesNoStrictNamingSy
 res = getUrl("http://localhost:"; + getPort() + "/blank");
 assertEquals("Cookie name fail", res.toString());
 res = getUrl("http://localhost:"; + getPort() + "/invalidFwd");
-assertEquals("Cookie name ok", res.toString());
+assertEquals("Cookie name fail", res.toString());
 res = getUrl("http://localhost:"; + getPort() + "/invalidStrict");
 assertEquals("Cookie name ok", res.toString());
 res = getUrl("http://localhost:"; + getPort() + "/valid");



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1747029 - in /tomcat/tc8.5.x/trunk: ./ test/javax/servlet/http/TestCookie.java test/org/apache/tomcat/util/http/CookiesBaseTest.java test/org/apache/tomcat/util/http/TestCookiesNoStrictNa

2016-06-06 Thread markt
Author: markt
Date: Mon Jun  6 15:20:50 2016
New Revision: 1747029

URL: http://svn.apache.org/viewvc?rev=1747029&view=rev
Log:
Unit test adjustments for change to default cookie name validator

Modified:
tomcat/tc8.5.x/trunk/   (props changed)
tomcat/tc8.5.x/trunk/test/javax/servlet/http/TestCookie.java
tomcat/tc8.5.x/trunk/test/org/apache/tomcat/util/http/CookiesBaseTest.java

tomcat/tc8.5.x/trunk/test/org/apache/tomcat/util/http/TestCookiesNoStrictNamingSysProps.java

Propchange: tomcat/tc8.5.x/trunk/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Mon Jun  6 15:20:50 2016
@@ -1 +1 @@
-/tomcat/trunk:1734785,1734799,1734845,1734928,1735041,1735044,1735480,1735577,1735597,1735599-1735600,1735615,1736145,1736162,1736209,1736280,1736297,1736299,1736489,1736646,1736703,1736836,1736849,1737104-1737105,1737112,1737117,1737119-1737120,1737155,1737157,1737192,1737280,1737339,1737632,1737664,1737715,1737748,1737785,1737834,1737860,1737959,1738005,1738007,1738014-1738015,1738018,1738022,1738039,1738043,1738059-1738060,1738147,1738149,1738174-1738175,1738261,1738589,1738623-1738625,1738643,1738816,1738850,1738855,1738946-1738948,1738953-1738954,1738979,1738982,1739079-1739081,1739087,1739113,1739153,1739172,1739176,1739191,1739474,1739726,1739762,1739775,1739814,1739817-1739818,1739975,1740131,1740324,1740465,1740495,1740508-1740509,1740520,1740535,1740707,1740803,1740810,1740969,1740980,1740991,1740997,1741015,1741033,1741036,1741058,1741060,1741080,1741147,1741159,1741164,1741173,1741181,1741190,1741197,1741202,1741208,1741213,1741221,1741225,1741232,1741409,1741501,1741677
 
,1741892,1741896,1741984,1742023,1742042,1742071,1742090,1742093,1742101,1742105,1742111,1742139,1742146,1742148,1742166,1742181,1742184,1742187,1742246,1742248-1742251,1742263-1742264,1742268,1742276,1742369,1742387,1742448,1742509-1742512,1742917,1742919,1742933,1742975-1742976,1742984,1742986,1743019,1743115,1743117,1743124-1743125,1743134,1743425,1743554,1743679,1743696-1743698,1743700-1743701,1744058,1744064-1744065,1744125,1744194,1744229,1744270,1744323,1744432,1744684,1744697,1744705,1744713,1744760,1744786,1745142-1745143,1745145,1745177,1745179-1745180,1745227,1745248,1745254,1745337,1745467,1745576,1745735,1745744,1746304,1746306-1746307,1746319,1746327,1746338,1746340-1746341,1746344,1746427,1746441,1746473,1746490,1746492,1746495-1746496,1746499-1746501,1746503-1746507,1746509,1746549,1746551,1746554,1746556,1746558,1746584,1746620,1746649,1746724,1746939,1746989,1747014
+/tomcat/trunk:1734785,1734799,1734845,1734928,1735041,1735044,1735480,1735577,1735597,1735599-1735600,1735615,1736145,1736162,1736209,1736280,1736297,1736299,1736489,1736646,1736703,1736836,1736849,1737104-1737105,1737112,1737117,1737119-1737120,1737155,1737157,1737192,1737280,1737339,1737632,1737664,1737715,1737748,1737785,1737834,1737860,1737959,1738005,1738007,1738014-1738015,1738018,1738022,1738039,1738043,1738059-1738060,1738147,1738149,1738174-1738175,1738261,1738589,1738623-1738625,1738643,1738816,1738850,1738855,1738946-1738948,1738953-1738954,1738979,1738982,1739079-1739081,1739087,1739113,1739153,1739172,1739176,1739191,1739474,1739726,1739762,1739775,1739814,1739817-1739818,1739975,1740131,1740324,1740465,1740495,1740508-1740509,1740520,1740535,1740707,1740803,1740810,1740969,1740980,1740991,1740997,1741015,1741033,1741036,1741058,1741060,1741080,1741147,1741159,1741164,1741173,1741181,1741190,1741197,1741202,1741208,1741213,1741221,1741225,1741232,1741409,1741501,1741677
 
,1741892,1741896,1741984,1742023,1742042,1742071,1742090,1742093,1742101,1742105,1742111,1742139,1742146,1742148,1742166,1742181,1742184,1742187,1742246,1742248-1742251,1742263-1742264,1742268,1742276,1742369,1742387,1742448,1742509-1742512,1742917,1742919,1742933,1742975-1742976,1742984,1742986,1743019,1743115,1743117,1743124-1743125,1743134,1743425,1743554,1743679,1743696-1743698,1743700-1743701,1744058,1744064-1744065,1744125,1744194,1744229,1744270,1744323,1744432,1744684,1744697,1744705,1744713,1744760,1744786,1745142-1745143,1745145,1745177,1745179-1745180,1745227,1745248,1745254,1745337,1745467,1745576,1745735,1745744,1746304,1746306-1746307,1746319,1746327,1746338,1746340-1746341,1746344,1746427,1746441,1746473,1746490,1746492,1746495-1746496,1746499-1746501,1746503-1746507,1746509,1746549,1746551,1746554,1746556,1746558,1746584,1746620,1746649,1746724,1746939,1746989,1747014,1747028

Modified: tomcat/tc8.5.x/trunk/test/javax/servlet/http/TestCookie.java
URL: 
http://svn.apache.org/viewvc/tomcat/tc8.5.x/trunk/test/javax/servlet/http/TestCookie.java?rev=1747029&r1=1747028&r2=1747029&view=diff
==
--- tomcat/tc8.5.x/trunk/test/javax/servlet/http/TestCookie.java (original)
+++ tomcat/tc8.5.x/trunk/test/javax/servlet/http/TestCookie.java Mon Jun  6 
15:20:50 2016
@@ -129,9 +129,9 @@ public class TestCookie {
 

buildbot success in on tomcat-trunk

2016-06-06 Thread buildbot
The Buildbot has detected a restored build on builder tomcat-trunk while 
building . Full details are available at:
https://ci.apache.org/builders/tomcat-trunk/builds/1434

Buildbot URL: https://ci.apache.org/

Buildslave for this Build: silvanus_ubuntu

Build Reason: The AnyBranchScheduler scheduler named 'on-tomcat-commit' 
triggered this build
Build Source Stamp: [branch tomcat/trunk] 1747028
Blamelist: markt

Build succeeded!

Sincerely,
 -The Buildbot




-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1747035 - in /tomcat/trunk: java/org/apache/tomcat/websocket/server/WsHttpUpgradeHandler.java webapps/docs/changelog.xml

2016-06-06 Thread markt
Author: markt
Date: Mon Jun  6 16:28:21 2016
New Revision: 1747035

URL: http://svn.apache.org/viewvc?rev=1747035&view=rev
Log:
Fix possible memory leak in WebSocket handling of unexpected client disconnects.

Modified:

tomcat/trunk/java/org/apache/tomcat/websocket/server/WsHttpUpgradeHandler.java
tomcat/trunk/webapps/docs/changelog.xml

Modified: 
tomcat/trunk/java/org/apache/tomcat/websocket/server/WsHttpUpgradeHandler.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/tomcat/websocket/server/WsHttpUpgradeHandler.java?rev=1747035&r1=1747034&r2=1747035&view=diff
==
--- 
tomcat/trunk/java/org/apache/tomcat/websocket/server/WsHttpUpgradeHandler.java 
(original)
+++ 
tomcat/trunk/java/org/apache/tomcat/websocket/server/WsHttpUpgradeHandler.java 
Mon Jun  6 16:28:21 2016
@@ -153,6 +153,7 @@ public class WsHttpUpgradeHandler implem
 CloseReason cr = new CloseReason(
 CloseCodes.CLOSED_ABNORMALLY, ioe.getMessage());
 close(cr);
+return SocketState.CLOSED;
 }
 break;
 case OPEN_WRITE:
@@ -168,6 +169,7 @@ public class WsHttpUpgradeHandler implem
 cr = new CloseReason(
 CloseCodes.CLOSED_ABNORMALLY, ioe.getMessage());
 close(cr);
+return SocketState.CLOSED;
 }
 break;
 case ERROR:

Modified: tomcat/trunk/webapps/docs/changelog.xml
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/webapps/docs/changelog.xml?rev=1747035&r1=1747034&r2=1747035&view=diff
==
--- tomcat/trunk/webapps/docs/changelog.xml (original)
+++ tomcat/trunk/webapps/docs/changelog.xml Mon Jun  6 16:28:21 2016
@@ -142,6 +142,14 @@
   
 
   
+  
+
+  
+59659: Fix possible memory leak in WebSocket handling of
+unexpected client disconnects. (markt)
+  
+
+  
   
 
   



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1747036 - in /tomcat/tc8.5.x/trunk: ./ java/org/apache/tomcat/websocket/server/WsHttpUpgradeHandler.java webapps/docs/changelog.xml

2016-06-06 Thread markt
Author: markt
Date: Mon Jun  6 16:28:44 2016
New Revision: 1747036

URL: http://svn.apache.org/viewvc?rev=1747036&view=rev
Log:
Fix possible memory leak in WebSocket handling of unexpected client disconnects.

Modified:
tomcat/tc8.5.x/trunk/   (props changed)

tomcat/tc8.5.x/trunk/java/org/apache/tomcat/websocket/server/WsHttpUpgradeHandler.java
tomcat/tc8.5.x/trunk/webapps/docs/changelog.xml

Propchange: tomcat/tc8.5.x/trunk/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Mon Jun  6 16:28:44 2016
@@ -1 +1 @@
-/tomcat/trunk:1734785,1734799,1734845,1734928,1735041,1735044,1735480,1735577,1735597,1735599-1735600,1735615,1736145,1736162,1736209,1736280,1736297,1736299,1736489,1736646,1736703,1736836,1736849,1737104-1737105,1737112,1737117,1737119-1737120,1737155,1737157,1737192,1737280,1737339,1737632,1737664,1737715,1737748,1737785,1737834,1737860,1737959,1738005,1738007,1738014-1738015,1738018,1738022,1738039,1738043,1738059-1738060,1738147,1738149,1738174-1738175,1738261,1738589,1738623-1738625,1738643,1738816,1738850,1738855,1738946-1738948,1738953-1738954,1738979,1738982,1739079-1739081,1739087,1739113,1739153,1739172,1739176,1739191,1739474,1739726,1739762,1739775,1739814,1739817-1739818,1739975,1740131,1740324,1740465,1740495,1740508-1740509,1740520,1740535,1740707,1740803,1740810,1740969,1740980,1740991,1740997,1741015,1741033,1741036,1741058,1741060,1741080,1741147,1741159,1741164,1741173,1741181,1741190,1741197,1741202,1741208,1741213,1741221,1741225,1741232,1741409,1741501,1741677
 
,1741892,1741896,1741984,1742023,1742042,1742071,1742090,1742093,1742101,1742105,1742111,1742139,1742146,1742148,1742166,1742181,1742184,1742187,1742246,1742248-1742251,1742263-1742264,1742268,1742276,1742369,1742387,1742448,1742509-1742512,1742917,1742919,1742933,1742975-1742976,1742984,1742986,1743019,1743115,1743117,1743124-1743125,1743134,1743425,1743554,1743679,1743696-1743698,1743700-1743701,1744058,1744064-1744065,1744125,1744194,1744229,1744270,1744323,1744432,1744684,1744697,1744705,1744713,1744760,1744786,1745142-1745143,1745145,1745177,1745179-1745180,1745227,1745248,1745254,1745337,1745467,1745576,1745735,1745744,1746304,1746306-1746307,1746319,1746327,1746338,1746340-1746341,1746344,1746427,1746441,1746473,1746490,1746492,1746495-1746496,1746499-1746501,1746503-1746507,1746509,1746549,1746551,1746554,1746556,1746558,1746584,1746620,1746649,1746724,1746939,1746989,1747014,1747028
+/tomcat/trunk:1734785,1734799,1734845,1734928,1735041,1735044,1735480,1735577,1735597,1735599-1735600,1735615,1736145,1736162,1736209,1736280,1736297,1736299,1736489,1736646,1736703,1736836,1736849,1737104-1737105,1737112,1737117,1737119-1737120,1737155,1737157,1737192,1737280,1737339,1737632,1737664,1737715,1737748,1737785,1737834,1737860,1737959,1738005,1738007,1738014-1738015,1738018,1738022,1738039,1738043,1738059-1738060,1738147,1738149,1738174-1738175,1738261,1738589,1738623-1738625,1738643,1738816,1738850,1738855,1738946-1738948,1738953-1738954,1738979,1738982,1739079-1739081,1739087,1739113,1739153,1739172,1739176,1739191,1739474,1739726,1739762,1739775,1739814,1739817-1739818,1739975,1740131,1740324,1740465,1740495,1740508-1740509,1740520,1740535,1740707,1740803,1740810,1740969,1740980,1740991,1740997,1741015,1741033,1741036,1741058,1741060,1741080,1741147,1741159,1741164,1741173,1741181,1741190,1741197,1741202,1741208,1741213,1741221,1741225,1741232,1741409,1741501,1741677
 
,1741892,1741896,1741984,1742023,1742042,1742071,1742090,1742093,1742101,1742105,1742111,1742139,1742146,1742148,1742166,1742181,1742184,1742187,1742246,1742248-1742251,1742263-1742264,1742268,1742276,1742369,1742387,1742448,1742509-1742512,1742917,1742919,1742933,1742975-1742976,1742984,1742986,1743019,1743115,1743117,1743124-1743125,1743134,1743425,1743554,1743679,1743696-1743698,1743700-1743701,1744058,1744064-1744065,1744125,1744194,1744229,1744270,1744323,1744432,1744684,1744697,1744705,1744713,1744760,1744786,1745142-1745143,1745145,1745177,1745179-1745180,1745227,1745248,1745254,1745337,1745467,1745576,1745735,1745744,1746304,1746306-1746307,1746319,1746327,1746338,1746340-1746341,1746344,1746427,1746441,1746473,1746490,1746492,1746495-1746496,1746499-1746501,1746503-1746507,1746509,1746549,1746551,1746554,1746556,1746558,1746584,1746620,1746649,1746724,1746939,1746989,1747014,1747028,1747035

Modified: 
tomcat/tc8.5.x/trunk/java/org/apache/tomcat/websocket/server/WsHttpUpgradeHandler.java
URL: 
http://svn.apache.org/viewvc/tomcat/tc8.5.x/trunk/java/org/apache/tomcat/websocket/server/WsHttpUpgradeHandler.java?rev=1747036&r1=1747035&r2=1747036&view=diff
==
--- 
tomcat/tc8.5.x/trunk/java/org/apache/tomcat/websocket/server/WsHttpUpgradeHandler.java
 (original)
+++ 
tomcat/tc8.5.x/trunk/java/org/apache/tomcat/websocket/server/WsHttpUpgradeHandler.java
 Mon Jun  6 16:28:44 2016
@@ -153

[Bug 59659] WsSession leaks (is not GC) if error occurs during the closing process

2016-06-06 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=59659

Mark Thomas  changed:

   What|Removed |Added

 Resolution|--- |FIXED
 Status|NEW |RESOLVED
 OS||All

--- Comment #1 from Mark Thomas  ---
Thanks for the report. This was introduced in the connector refactoring so
8.0.x and earlier are not affected.

It has been fixed in 9.0.x for 9.0.0.M7 onwards and 8.5.x for 8.5.3 onwards.

-- 
You are receiving this mail because:
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 59650] NIO2 connector does not respect executor bounds, reuses NIO.2 threads for processing request on connections

2016-06-06 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=59650

--- Comment #8 from Remy Maucherat  ---
That's a useful clarification actually, the standard executor is not an
ExecutorService, there's another thread pool in there that is an
ExecutorService. It is likely I'll adjust the connector startup logging to make
it clear a separate executor should probably not be used with NIO2.

-- 
You are receiving this mail because:
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1747014 - in /tomcat/trunk: java/javax/servlet/http/Cookie.java webapps/docs/changelog.xml webapps/docs/config/systemprops.xml

2016-06-06 Thread markt
Author: markt
Date: Mon Jun  6 14:17:16 2016
New Revision: 1747014

URL: http://svn.apache.org/viewvc?rev=1747014&view=rev
Log:
Fix https://bz.apache.org/bugzilla/show_bug.cgi?id=59655
Configure the cookie name validation to use RFC6265 rules by default to align 
it with the default cookie parser. Document the impact system properties have 
on cookie name validation.

Modified:
tomcat/trunk/java/javax/servlet/http/Cookie.java
tomcat/trunk/webapps/docs/changelog.xml
tomcat/trunk/webapps/docs/config/systemprops.xml

Modified: tomcat/trunk/java/javax/servlet/http/Cookie.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/javax/servlet/http/Cookie.java?rev=1747014&r1=1747013&r2=1747014&view=diff
==
--- tomcat/trunk/java/javax/servlet/http/Cookie.java (original)
+++ tomcat/trunk/java/javax/servlet/http/Cookie.java Mon Jun  6 14:17:16 2016
@@ -49,7 +49,7 @@ import java.util.ResourceBundle;
  * support the cache control defined with HTTP 1.1.
  * 
  * This class supports both the Version 0 (by Netscape) and Version 1 (by RFC
  * 2109) cookie specifications. By default, cookies are created using Version 0
  * to ensure the best interoperability.
  */
 public class Cookie implements Cloneable, Serializable {
@@ -68,7 +68,7 @@ public class Cookie implements Cloneable
 validation = new RFC2109Validator();
 }
 else {
-validation = new NetscapeValidator();
+validation = new RFC6265Validator();
 }
 }
 
@@ -49,7 +49,7 @@ import java.util.ResourceBundle;
  * 
  * This class supports both the Version 0 (by Netscape) and Version 1 (by RFC
- * 2109) cookie specifications. By default, cookies are created using Version 0
+ * 2109) cookie specifications. By default, cookies are created using RFC6265
  * to ensure the best interoperability.
  */

Modified: tomcat/trunk/webapps/docs/changelog.xml
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/webapps/docs/changelog.xml?rev=1747014&r1=1747013&r2=1747014&view=diff
==
-- 
You are receiving this mail because:
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 59664] BufferReader return fuzzied when use https transfer Unicode char

2016-06-06 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=59664

Mark Thomas  changed:

   What|Removed |Added

 Resolution|--- |INVALID
 Status|NEW |RESOLVED

--- Comment #1 from Mark Thomas  ---
Bugzilla is not a support forum. Please use the Tomcat users' mailing list for
assistance.

There are multiple reasons I am resolving this as invalid.
- The statement in the bug report "0 means the stream is ended" is incorrect
- With blocking IO (as available from a JSP) a zero length read is not possible
- BufferedReader is a Java SE class, not a Tomcat class
- A simple test case that sends UTF-8 data byte by byte over TLS works as
expected with both 7.0.x trunk and 9.0.x trunk

-- 
You are receiving this mail because:
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Tagging 9.0.x, 8.5.x, 8.0.x

2016-06-06 Thread Mark Thomas
Hi,

I've just finished reviewing the open bugs so, barring any new bugs
appearing over night, I plan to start the release process for the
branches in the subject line tomorrow (in around 12 hours).

Mark

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 59668] New: x:forEach retains the incorrect scope when used in a tag called from another x:forEach

2016-06-06 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=59668

Bug ID: 59668
   Summary: x:forEach retains the incorrect scope when used in a
tag called from another x:forEach
   Product: Taglibs
   Version: unspecified
  Hardware: PC
OS: Mac OS X 10.1
Status: NEW
  Severity: normal
  Priority: P2
 Component: XTags Taglib
  Assignee: dev@tomcat.apache.org
  Reporter: matthewcasper...@gmail.com

This is related to https://github.com/mcasperson/wildfly_jstl_bug/

There is a bug that occurs when you have a x:forEach in a JSP page, and inside
this x:forEach you call a tag that itself has a x:forEach. The variable created
by the second x:forEach is inaccessible to any nested x:out elements.

This happens because the x:out pagecontext is assigned from the parent
x:forEach (from the tag file), which in turn has its pageContext assigned from
its parent x:forEach (from the JSP page). This means the x:out element has no
access to page scoped variables from the tag.

This bug is known to affect WildFly 10.0.0, which uses code forked from the
Apache TagLib project. See
https://github.com/mcasperson/wildfly_jstl_bug/blob/master/src/main/webapp/index.jsp
and
https://github.com/mcasperson/wildfly_jstl_bug/blob/master/src/main/webapp/WEB-INF/tags/my.tag
for more details. When run, this JSP page produces the exception:

Caused by: javax.xml.transform.TransformerException: Could not resolve XPath
variable: $childNode
at
org.apache.taglibs.standard.tag.common.xml.JSTLVariableStack.getVariableOrParam(JSTLVariableStack.java:93)
at org.apache.xpath.operations.Variable.execute(Variable.java:219)
at org.apache.xpath.operations.Variable.execute(Variable.java:188)
at
org.apache.xpath.axes.FilterExprIteratorSimple.executeFilterExpr(FilterExprIteratorSimple.java:116)
at
org.apache.xpath.axes.FilterExprWalker.setRoot(FilterExprWalker.java:131)
at
org.apache.xpath.axes.WalkingIterator.setRoot(WalkingIterator.java:157)
at
org.apache.xpath.axes.NodeSequence.setRoot(NodeSequence.java:265)
at
org.apache.xpath.axes.LocPathIterator.execute(LocPathIterator.java:212)
at org.apache.xpath.XPath.execute(XPath.java:337)
... 41 more

We have a fix which you can view at
https://github.com/jboss/jboss-jstl-api_spec/pull/12/files/e0b0140c879c43c8dc2cc881e5cd3d857935d685..b03bea7ad4d3a92a16d8a9f67434cf033f72ca09.
It is a nasty hack so I am not suggesting this is how the problem should be
solved, but it does demonstrate how pageContexts are being incorrectly assigned
with the x:forEach element and nested tags.

-- 
You are receiving this mail because:
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org